'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _semanticUiReact = require('semantic-ui-react');

var _reactCfHelperCdn = require('react-cf-helper-cdn');

var _reactCfHelperCdn2 = _interopRequireDefault(_reactCfHelperCdn);

var _reactRouterDom = require('react-router-dom');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Avatar
 * @param {String} avatar
 */
var Avatar = function Avatar(_ref) {
  var url = _ref.url;
  return _react2.default.createElement(_semanticUiReact.Image, { avatar: true, src: url });
};

var About = function About(_ref2) {
  var url = _ref2.url,
      name = _ref2.name,
      email = _ref2.email;
  return _react2.default.createElement(
    _semanticUiReact.Segment,
    { basic: true, textAlign: 'center' },
    _react2.default.createElement(_semanticUiReact.Image, { avatar: true, src: url, size: 'tiny' }),
    _react2.default.createElement(
      _semanticUiReact.Header,
      { as: 'h4' },
      name
    ),
    _react2.default.createElement(
      _semanticUiReact.Header.Subheader,
      null,
      email
    )
  );
};

/**
 * Profile
 * @param {String} avatarUrl
 */
var Profile = function Profile(_ref3) {
  var avatarUrl = _ref3.avatarUrl,
      name = _ref3.name,
      email = _ref3.email,
      onLogout = _ref3.onLogout;

  var trigger = _react2.default.createElement(Avatar, { url: avatarUrl });
  return _react2.default.createElement(
    _semanticUiReact.Dropdown,
    { item: true, trigger: trigger },
    _react2.default.createElement(
      _semanticUiReact.Dropdown.Menu,
      null,
      _react2.default.createElement(_semanticUiReact.Dropdown.Item, {
        as: _reactRouterDom.Link,
        to: '/account/user/me',
        text: _react2.default.createElement(About, {
          url: avatarUrl,
          name: name,
          email: email
        })
      }),
      _react2.default.createElement(_semanticUiReact.Dropdown.Divider, null),
      _react2.default.createElement(_semanticUiReact.Dropdown.Item, {
        onClick: function onClick() {
          return onLogout(true);
        },
        icon: 'sign out',
        text: 'Cerrar sesi\xF3n'
      })
    )
  );
};

Profile.defaultProps = {
  avatarUrl: _reactCfHelperCdn2.default.image('avatar-default-80-80.svg'),
  name: '...',
  email: '...'
};

Profile.propTypes = {
  avatarUrl: _propTypes2.default.string,
  name: _propTypes2.default.string,
  email: _propTypes2.default.string,
  onLogout: _propTypes2.default.func.isRequired
};

Avatar.propTypes = {
  url: _propTypes2.default.string.isRequired
};

About.propTypes = {
  url: _propTypes2.default.string.isRequired,
  name: _propTypes2.default.string.isRequired,
  email: _propTypes2.default.string.isRequired
};

exports.default = Profile;